{% extends base_template|default:"handyhelpers_base.htm" %}
{% load staticfiles %}

{% block content %}
    <!-- Page header -->
    <section class="animated fadeIn">
        <header class="m-5">
            <div class="headline text-center">
                <div class="container">
                    <div class="h1 text-primary font-weight-bold mb-3">{{ title|safe }}</div>
                    <div class="h5 text-secondary">{{ subtitle|safe }}</div>
                </div>
            </div>
        </header>
    </section>

    <!-- Page Content -->
    <section class="animated fadeIn" style="animation-delay: .25s;">
        <div class="container mb-3">
            <div class="row">
                <div class="col-sm-2">
                    <div class="text-primary" style="font-size: 60px; text-align: left; vertical-align: top;">
                        <i class="fa fa-exclamation-triangle"></i>
                    </div>
                </div>
                <div class="col-sm-10">
                    <p>{{ message }}</p>
                    <table class='table borderless'>
                        <col width="25%">
                        <col width="75%">
                        <tr style="border-bottom: 1px solid whitesmoke;">
                            <td><span class="text-primary font-weight-bold">Host:</span></td>
                            <td>{{ request.META.HTTP_HOST }}</td>
                        </tr>
                        <tr style="border-bottom: 1px solid whitesmoke;">
                            <td><span class="text-primary font-weight-bold">Path:</span></td>
                            <td>{{ request.META.PATH_INFO }}</td>
                        </tr>
                        <tr style="border-bottom: 1px solid whitesmoke;">
                            <td><span class="text-primary font-weight-bold">Method:</span></td>
                            <td>{{ request.META.REQUEST_METHOD }}</td>
                        </tr>
                        <tr style="border-bottom: 1px solid whitesmoke;">
                            <td><span class="text-primary font-weight-bold">Referrer:</span></td>
                            <td>{{ request.META.HTTP_REFERER }}</td>
                        </tr>
                    </table>
                    <br/><p><b><a class="text-primary" href="{% url 'home' %}">Return to the home page</a></b></p>
                </div>
            </div>
        </div>
    </section>

{% endblock %}
